'<SCRIPT Language=VBScript>

' THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT
' WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED,
' INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES
' OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR
' PURPOSE
'
' You are free to use this code within your own applications,
' but you are expressly forbidden from selling or otherwise
' distributing this source code without prior written consent.
' This includes both posting free demo projects made from this
' code as well as reproducing the code in any other format.
'
'------------------------------------------------------------------------------
'
' NAME: SaveAttachment.vbs
'
' DESCRIPTION: Saves the attachments of an item that arrive in a particular
'              folder and removes them from the item
'
' Copyright (c) CDOLive LLC 1998-2002, Siegfried Weber. All rights reserved.
'               http://www.cdolive.net/samples/saveattachment.eml
'               mailto:samples@cdolive.com?subject=SaveAttachment
'
'------------------------------------------------------------------------------

' Declare Event Sink constants
Const EVT_ERROR = &H80000000
Const EVT_INVALID_URL = &H40000000
Const EVT_INITNEW = &H40
Const EVT_NEW_ITEM = 1
Const EVT_IS_COLLECTION = 2
Const EVT_REPLICATED_ITEM = 4
Const EVT_IS_DELIVERED = 8
Const EVT_SOFTDELETE = &H10
Const EVT_HARDDELETE = &H20
Const EVT_MOVE = &H100
Const EVT_COPY = &H200
Const EVT_SYNC_COMMITTED = &H2000000
Const EVT_SYNC_ABORTED = &H4000000

' Declare ADO constants
Const adModeUnknown = 0
Const adModeRead = 1
Const adModeWrite = 2
Const adModeReadWrite = 3
Const adCreateCollection = &H2000
Const adCreateNonCollection = 0
Const adCreateOverwrite = &H4000000
Const adCreateStructDoc = &H80000000
Const adFailIfNotExists = &HFFFFFFFF
Const adOpenIfExists = &H2000000
Const adSaveCreateNotExist = 1
Const adSaveCreateOverWrite = 2
Const adFldCacheDeferred = &H1000
Const adFldFixed = &H10
Const adFldIsChapter = &H2000
Const adFldIsCollection = &H40000
Const adFldIsDefaultStream = &H20000
Const adFldIsNullable = &H20
Const adFldIsRowURL = &H10000
Const adFldKeyColumn = &H8000
Const adFldLong = &H80
Const adFldMayBeNull = &H40
Const adFldMayDefer = 2
Const adFldNegativeScale = &H4000
Const adFldRowID = &H100
Const adFldRowVersion = &H200
Const adFldUnknownUpdatable = 8
Const adFldUpdatable = 4

' Declare filesystem object constants
Const ForReading = 1
Const ForWriting = 2
Const ForAppending = 8

' Debug file path, change it to the location you want to store
' debug information
Const DEBUG_LOG_PATH = "D:\SaveAttachment\"

' Name of debug log file
' Change this to the name you want to use
Const DEBUG_FILE = "SaveAttachment.log"

' Set this variable to false if you don't want to get any debug info
Const ENABLE_DEBUG_LOG = True

' Drive and directory where attachments should be stored
' Change this to a valid drive and directory on your system
' and make sure the account used to run this script has proper
' permission to write to this directory
Const FILE_PATH = "D:\SaveAttachment\"

Sub ExStoreEvents_OnSave(ptrEventInfo, bstrURLItem, lngFlags)

  ' Initialize error checking
  On Error Resume Next

  ' Declare variables
  Dim objFileSystem    ' As Scripting.FileSystemObject
  Dim objFile        ' As Scripting.TextStream
  Dim objDataSource    ' As CDO.IDataSource
  Dim objMessage      ' As CDO.Message
  Dim objAttachments    ' As CDO.IBodyParts
  Dim objAttachment    ' As CDO.IBodyPart
  Dim blnLogFileOpen    ' As Boolean

  ' Initialize variables
  Set objFileSystem = CreateObject("Scripting.FileSystemObject")    ' = New Scripting.FileSystemObject
  Set objMessage = CreateObject("CDO.Message")
  Set objDataSource = objMessage.GetInterface("IDataSource")
  blnLogFileOpen = False

  ' Check if debug log path is not empty
  If ENABLE_DEBUG_LOG = True Then

    ' Open debug logfile
    Err.Clear
    Set objFile = objFileSystem.OpenTextFile(DEBUG_LOG_PATH & DEBUG_FILE, ForAppending, True)

    ' Check for errors
    If Err.Number = 0 Then

      ' Set flag that we have a valid handle to the debug file
      blnLogFileOpen = True
    End IF
  End IF

  ' Check if its a new item
  If (lngFlags And EVT_IS_DELIVERED) Or (lngFlags And EVT_NEW_ITEM) Then

    ' Write debug info
    If blnLogFileOpen = True Then
      With objFile
        .WriteLine "##################################################################################################"
        .WriteLine "Event for mail-submitted message has been fired, " & Now
        .WriteLine "Item URL: " & bstrURLItem
        .WriteLine "lngFlags: " & "0x" & Hex(lngFlags)
      End With
    End If

    ' Write debug info
    If blnLogFileOpen = True Then
      objFile.WriteLine "Attempting to open item: " & bstrURLItem
    End If

    ' Get item as CDOEX message
    Err.Clear
    objDataSource.Open bstrURLItem, , , adModeRead, adFailIfNotExists
    If Err.Number = 0 Then

      ' Save attachments
      With objMessage

        ' Write debug info
        If blnLogFileOpen = True Then
          objFile.WriteLine "Item opened: " & .Subject
        End If

        ' Get attachments collection
        Err.Clear
        Set objAttachments = objMessage.Attachments
        If Err.Number <> 0 Then

          ' Write debug info
          If blnLogFileOpen = True Then
            objFile.WriteLine "Error opening attachments: " & Err.Number & " Description " & Err.Description
          End If
        Else

          ' Check if attachment collection is not empty
          If objAttachments.Count <> 0 Then

            ' Write debug info
            If blnLogFileOpen = True Then
              objFile.WriteLine "Attachment count: " & objAttachments.Count
            End If

            ' Loop through attachments collection
            For Each objAttachment In objAttachments

              ' Write debug info
              If blnLogFileOpen = True Then
                objFile.WriteLine "Attachment filename: " & objAttachment.FileName
              End If

              ' Save each attachment to file system
              objAttachment.SaveToFile FILE_PATH & objAttachment.FileName
            Next

            ' Delete all attachments
            objAttachments.DeleteAll
          End If
        End If
      End With

      ' Save changes to message
      objDataSource.Save
    End If

    ' Write debug info
    If blnLogFileOpen = True Then
      objFile.WriteLine "Finished Event for new item or mail-submitted message, " & Now
    End If
  End If

  ' Close debug logfile
  If blnLogFileOpen = True Then
    objFile.Close
  End IF

  ' Tidy up
  Set objFileSystem = Nothing
  Set objFile = Nothing
  Set objDataSource = Nothing
  Set objMessage = Nothing
  Set objAttachments = Nothing
  Set objAttachment = Nothing
End Sub

'</SCRIPT>
